@@ -17,8 +17,9 @@ class AppEnvironmentFilter(NetBoxModelFilterSet):
 
     class Meta:
         model = AppEnvironment
-        fields = ["app_env", "mtls", "repo", "branch", "path", "egress_ip", "deployment_kind", "monitoring", "postgres_monitoring",
-                  "ocp_project"]
+        fields = ["access_token", "cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip",
+                  "deployment_kind", "monitoring", "postgres_monitoring", "ocp_project", "requests_cpu",
+                  "requests_memory", "limits_cpu", "limits_memory"]
 
     def search(self, queryset, name, value):
         """Perform the filtered search."""
@@ -34,5 +35,9 @@ class AppEnvironmentFilter(NetBoxModelFilterSet):
             | Q(deployment_kind__icontains=value)
             | Q(monitoring__icontains=value)
             | Q(postgres_monitoring__icontains=value)
+            | Q(limits_cpu__icontains=value)
+            | Q(limits_memory__icontains=value)
+            | Q(requests_cpu__icontains=value)
+            | Q(requests_memory__icontains=value)
         )
         return queryset.filter(qs_filter)
