@@ -1,3 +1,4 @@
+from django.core.validators import RegexValidator
 from django.forms import (
     CharField,
     BooleanField, PasswordInput,
@@ -13,8 +14,18 @@ from ocp_project_plugin.models import AppEnvironment, OCPProject
 from utilities.forms import DynamicModelChoiceField
 
 
+memory_validator = RegexValidator(r"[1-9][0-9]*(Mi|Gi)$", "The input should contain only positive Number, which ends "
+                                                          "with Mi (Megabyte) or Gi (Gigabyte)")
+
+
 class AppEnvironmentForm(NetBoxModelForm):
     """Form for creating a new App Environment object."""
+    #requests_memory = CharField(
+    #    max_length=5,
+    #    label="Memory request",
+    #    help_text="The memory value e.g. 200Mi or 1Gi",
+    #    validators=[memory_validator],
+    #)
     ocp_project = DynamicModelChoiceField(
         queryset=OCPProject.objects.all(),
         label="OCP Project",
