@@ -1,13 +1,24 @@
 import logging
-
-from django.db.models import CharField, BooleanField, ForeignKey, CASCADE, OneToOneField, SET_NULL, PROTECT
+from decimal import Decimal
+from django.core.validators import RegexValidator
+from django.db.models import CharField, BooleanField, ForeignKey, CASCADE, OneToOneField, SET_NULL, PROTECT, \
+    DecimalField
 from django.urls import reverse
 from django_rq import get_queue
 
+from netbox import settings
 from ocp_project_plugin.choices import AppEnvironmentClusterEnvChoices, AppEnvironmentDeploymentKindChoices
 
 from netbox.models import NetBoxModel
 
+PLUGIN_SETTINGS = settings.PLUGINS_CONFIG.get('ocp_project_plugin', dict())
+CPU_COST = PLUGIN_SETTINGS.get('cpu_cost', '')
+MEMORY_COST = PLUGIN_SETTINGS.get('memory_cost', '')
+STORAGE_COST = PLUGIN_SETTINGS.get('storage_cost', '')
+
+memory_validator = RegexValidator(r"[1-9][0-9]*(Mi|Gi)$", "The input should contain only positive Number, which ends "
+                                                          "with Mi (Megabyte) or Gi (Gigabyte)")
+
 
 class OCPProject(NetBoxModel):
     name = CharField(
@@ -159,8 +170,9 @@ class AppEnvironment(NetBoxModel):
         verbose_name="Postgres Monitoring",
         help_text="Enable if postgres monitoring should be used",
     )
-    requests_cpu = CharField(
-        max_length=5,
+    requests_cpu = DecimalField(
+        max_digits=4,
+        decimal_places=2,
         blank=True,
         verbose_name="CPU request",
         help_text="The CPU request value e.g. 1",
@@ -170,9 +182,11 @@ class AppEnvironment(NetBoxModel):
         blank=True,
         verbose_name="Memory request",
         help_text="The memory value e.g. 200Mi or 1Gi",
+        validators=[memory_validator],
     )
-    limits_cpu = CharField(
-        max_length=5,
+    limits_cpu = DecimalField(
+        max_digits=4,
+        decimal_places=2,
         blank=True,
         verbose_name="CPU Limit",
         help_text="The CPU request value e.g. 2",
@@ -182,6 +196,7 @@ class AppEnvironment(NetBoxModel):
         blank=True,
         verbose_name="Memory Limit",
         help_text="The CPU memory value e.g. 400Mi or 2Gi",
+        validators=[memory_validator],
     )
     ocp_project = ForeignKey(OCPProject, on_delete=CASCADE, related_name="app_env_ocp_project")
 
@@ -205,16 +220,26 @@ class AppEnvironment(NetBoxModel):
         return f'https://confluence.ti8m.ch/docs/models/AppEnvironment/'
 
     def save(self, *args, **kwargs):
-        logger = logging.getLogger('netbox.ocp_project_plugin')
-
-        logger.warning(f'{self}')
-        logger.warning(f'{self.ocp_project}')
-
         get_queue("default").enqueue("ocp_project_plugin.worker.pull_repository")
-    #    clone_repo()
-    #    super(AppEnvironment, self).save(*args, **kwargs)
+        super(AppEnvironment, self).save(*args, **kwargs)
 
     def get_cluster_color(self):
         return AppEnvironmentClusterEnvChoices.colors.get(self.cluster_env)
 
+    def get_limits_memory_gi(self):
+        if self.limits_memory is '':
+            return 0
+        else:
+            if str(self.limits_memory).endswith('Mi'):
+                return int(MEMORY_COST) * float(str(self.limits_memory)[:-2]) / 1000
+            else:
+                return int(MEMORY_COST) * float(str(self.limits_memory)[:-2])
 
+    def calculate_cpu_cost(self):
+        return Decimal(CPU_COST) * DecimalField().to_python(self.limits_cpu)
+
+    def calculate_memory_cost(self):
+        if self.limits_memory is '':
+            return '0'
+        else:
+            return int(MEMORY_COST) * float(str(self.limits_memory)[:-2])
