@@ -24,6 +24,9 @@ class AppEnvironmentTable(NetBoxTable):
     branch = tables.Column(
         linkify=True
     )
+    ocp_project = tables.Column(
+        linkify=True
+    )
 
     class Meta(NetBoxTable.Meta):
         model = AppEnvironment
@@ -32,5 +35,5 @@ class AppEnvironmentTable(NetBoxTable):
                   "monitoring", "postgres_monitoring", "ocp_project", "requests_cpu", "requests_memory", "limits_cpu",
                   "limits_memory"]
 
-        default_columns = ["cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip", "deployment_kind",
+        default_columns = ["cluster_env", "app_env", "mtls", "repo", "branch", "path", "deployment_kind",
                            "monitoring", "postgres_monitoring", "ocp_project"]
