@@ -57,7 +57,10 @@ def calculate_memory_cost(amount):
     if amount is '':
         return '-'
     else:
-        return int(MEMORY_COST) * float(str(amount)[:-2])
+        if amount.endswith('Mi'):
+            return int(MEMORY_COST) * float(str(amount)[:-2]) / 1000
+        else:
+            return int(MEMORY_COST) * float(str(amount)[:-2])
 
 
 @register.simple_tag
@@ -68,7 +71,7 @@ def get_memory_cost():
 @register.simple_tag
 def calculate_storage_cost(amount):
     if amount is '':
-        return '-'
+        return '0'
     else:
         return int(STORAGE_COST) * int(amount)
 
@@ -80,8 +83,10 @@ def get_storage_cost():
 
 @register.simple_tag
 def calculate_total_cost(cpu_amount, memory_amount, storage_amount):
+    print(cpu_amount)
+    print(memory_amount)
     if cpu_amount is '' or memory_amount is '':
-        return '-'
+        return '0'
     else:
         return int(CPU_COST) * int(cpu_amount) + int(MEMORY_COST) * float(str(memory_amount)[:-2]) + int(STORAGE_COST) \
             * int(storage_amount)
