@@ -1,3 +1,9 @@
+from django.db.models import Sum, FloatField, IntegerField, DecimalField
+from django.db.models.functions import Cast
+
+from decimal import Decimal
+
+from netbox import settings
 from netbox.views.generic import ObjectView, ObjectListView, ObjectEditView, ObjectDeleteView, BulkImportView, \
     BulkEditView, BulkDeleteView
 
@@ -12,6 +18,11 @@ from ocp_project_plugin.models import OCPProject, AppEnvironment
 from ocp_project_plugin.tables import OCPProjectTable, AppEnvironmentTable
 from utilities.views import register_model_view
 
+PLUGIN_SETTINGS = settings.PLUGINS_CONFIG.get('ocp_project_plugin', dict())
+CPU_COST = PLUGIN_SETTINGS.get('cpu_cost', '')
+MEMORY_COST = PLUGIN_SETTINGS.get('memory_cost', '')
+STORAGE_COST = PLUGIN_SETTINGS.get('storage_cost', '')
+
 
 class OCPProjectListView(ObjectListView):
     queryset = OCPProject.objects.all()
@@ -64,10 +75,33 @@ class OCPProjectView(ObjectView):
         assignments_table = AppEnvironmentTable(app_environment_assignments, user=request.user)
         assignments_table.configure(request)
 
+        total_cpu = 0
+        total_memory = 0
+        total_storage = 0
+        total_cpu_cost = 0
+        total_memory_cost = 0
+        total_storage_cost = 0
+        for app_env in app_environment_assignments:
+            total_cpu = + DecimalField().to_python(app_env.limits_cpu)
+
+        for app_env in app_environment_assignments:
+            total_memory = + app_env.get_limits_memory_gi()
+            # total_cpu_cost = + app_env.calculate_cpu_cost()
+            # print(app_env.calculate_memory_cost())
+
+        total_cpu_cost = Decimal(CPU_COST) * Decimal(total_cpu)
+        total_memory_cost = Decimal(MEMORY_COST) * Decimal(total_memory)
+        total_cost = total_cpu_cost + total_memory_cost + total_storage_cost
+
         return {
             'assignments_table': assignments_table,
             'assignment_count': AppEnvironment.objects.filter(ocp_project=instance).count(),
-            'app_env_list': AppEnvironment.objects.filter(ocp_project=instance)
+            'app_env_list': AppEnvironment.objects.filter(ocp_project=instance),
+            'total_cpu': total_cpu,
+            'total_memory': total_memory,
+            'total_storage': total_storage,
+            'total_cpu_cost': total_cpu_cost,
+            'total_memory_cost': total_memory_cost,
+            'total_storage_cost': total_storage_cost,
+            'total_cost': total_cost
         }
-
-
